@@ -71,17 +71,14 @@ typedef struct {
 	gdouble alt;				/* 高度(m) */
 
 	/* tilt なしの状態で真上から見たときに見える範囲(degree) */
-	gdouble deg_view_lon_l;		/* 地平線近くまで含めた広い版 */
+	/* 地平線近くまで含めた広い版 */
+	gdouble deg_view_lon_l;
 	gdouble deg_view_lat_l;
-	gdouble deg_view_lon_s;		/* 真上から見たときに画面に収まる程度＋αという狭い版 */
+	/* 真上から見たときに画面に収まる程度＋αという狭い版 */
+	gdouble deg_view_lon_s;
 	gdouble deg_view_lat_s;
 
-	/* 真上から見たときに画面がおさまる程度の円の半径 */
-	gdouble deg_view_r;
-
 	gboolean inertia;
-
-	gdouble fovy;
 } Camera;
 
 static Camera *camera;
@@ -98,7 +95,7 @@ calc_camera (void)
 	gdouble yaw_target;
 	gdouble pitch_target;
 	gdouble roll_target;
-	gdouble r = mmap_get_world_radius ();
+	gdouble r;
 
 	quaternion_to_matrix (camera->q, camera->rt);	/* クォータニオンから回転の変換行列を求める */
 
@@ -116,6 +113,8 @@ calc_camera (void)
 		camera->heading -= 360.0;
 	}
 
+	r = mmap_get_world_radius ();
+
 	if (camera->type == CAMERA_TYPE_NWW) {
 		camera->alt = sqrt (camera->dist * camera->dist + r * r + 2.0 * camera->dist * r * cos (RAD (camera->tilt))) - r;
 	} else {
@@ -135,47 +134,53 @@ calc_camera (void)
 
 	{
 		/* 視野範囲は、最終目的地 (**_target) から計算する。 */
-		gdouble l;				/* 真下を見下ろした時の視界の距離。ものすごくテキトーな計算 */
-		gdouble m;				/* 緯度が上がるにしたがい経度方向の幅を増やすための係数 */
-		gdouble k;				/* 高度を下げるにしたがい、視野範囲をしぼるための係数 */
-		gdouble angle;			/* 地平線まで全部表示するための角度 */
+		gdouble l;
+		gdouble m;
+		gdouble k;
+		gdouble angle_v;		/* 地平線まで全部表示するための角度 */
+		gdouble angle;
 
-		l = 2.0 * camera->dist_target * tan (RAD (camera->fovy / 2.0));
-		angle = acos (r / (r + camera->dist_target));
+		angle_v = acos (r / (r + camera->dist_target));
+		/*
+		   g_print("angle:%.2f\n", DEG(angle_v));
+		 */
 
+		/* 緯度が上がるにしたがい経度方向の幅を増やすための係数 */
 		m = cos (RAD (camera->lat_target));
 		if (m < 0.2) {
 			m = 0.2;
+		} else {
+			;
 		}
 
+		/* 高度を下げるにしたがい、視野範囲をしぼるための係数 */
 		{
-			gdouble a = 0.9;	/* 高度 3*r の時の係数 */
-			gdouble b = 0.2;	/* 高度 0 の時の係数 */
+			gdouble a = 0.8;	/* 高度 3*r の時の係数 */
+			gdouble b = 0.3;	/* 高度 0 の時の係数 */
 			if (camera->dist_target > 3.0 * r) {
 				k = a;
 			} else {
 				k = (a - b) / (3.0 * r) * camera->dist_target + b;
 			}
 		}
-		camera->deg_view_lat_l = 2.0 * DEG (angle) * k;
+		camera->deg_view_lat_l = 2.0 * DEG (angle_v) * k;
 		camera->deg_view_lon_l = camera->deg_view_lat_l / m;
 
-		camera->deg_view_r = 2.0 * DEG (atan (l / 2.0 / r));
-		camera->deg_view_lat_s = camera->deg_view_r * 1.6;
+		angle = 65.0;
+		/*
+		   g_print ("angle:%.2f  m:%.2f\n", angle, m);
+		 */
+		/* 真下を見下ろした時の視界の距離。ものすごくテキトーな計算 */
+		l = 2.0 * camera->dist_target * tan (RAD (angle / 2.0));
+		camera->deg_view_lat_s = 2.0 * DEG (atan (l / 2.0 / r));
 		camera->deg_view_lon_s = camera->deg_view_lat_s / m;
 
-		if (camera->deg_view_lat_s > camera->deg_view_lat_l) {
-			camera->deg_view_lat_s = camera->deg_view_lat_l;
-		}
-		if (camera->deg_view_lon_s > camera->deg_view_lon_l) {
-			camera->deg_view_lon_s = camera->deg_view_lon_l;
-		}
-
-		/* 360 だと幅ゼロだと見られてしまうの少し小さくする */
 		if (camera->deg_view_lon_l >= 360.0) {
+			/* 360 だと幅ゼロだと見られてしまうの少し小さくする */
 			camera->deg_view_lon_l = 359.9;
 		}
 		if (camera->deg_view_lon_s >= 360.0) {
+			/* 360 だと幅ゼロだと見られてしまうの少し小さくする */
 			camera->deg_view_lon_s = 359.9;
 		}
 		/*
@@ -314,6 +319,9 @@ motion_sub (gdouble * target, gdouble * current, gdouble limit, gdouble point, g
 	return finished;
 }
 
+/*****************************************************/
+
+
 /*****************************************************/
 
 static gboolean
@@ -672,23 +680,9 @@ camera_next_step (void)
 /*****************************************************/
 
 void
-camera_matrix_prepare (gint width, gint height)
+camera_matrix_prepare (void)
 {
-	gdouble l = 1000.0;
 	gdouble r = mmap_get_world_radius ();
-	gdouble near, far;
-
-	glMatrixMode (GL_PROJECTION);
-	glLoadIdentity ();
-
-	camera->fovy = 2.0 * DEG (atan ((height / 2.0) / l));
-	near = camera->dist * 0.2;
-	far = (r + camera->dist) * 2.0;
-	/*
-	   g_print("fovy:%.2f  near:%.2f  far:%.2f\n", camera->fovy, near, far);
-	 */
-
-	gluPerspective (camera->fovy, (gdouble) width / height, near, far);
 
 	glMatrixMode (GL_MODELVIEW);
 	glLoadIdentity ();
@@ -744,18 +738,6 @@ camera_get_dist (void)
 	return camera->dist;
 }
 
-gdouble
-camera_get_lon_target (void)
-{
-	return camera->lon_target;
-}
-
-gdouble
-camera_get_lat_target (void)
-{
-	return camera->lat_target;
-}
-
 gdouble
 camera_get_dist_target (void)
 {
@@ -1038,15 +1020,3 @@ camera_get_inertia (void)
 {
 	return camera->inertia;
 }
-
-gdouble
-camera_get_fovy (void)
-{
-	return camera->fovy;
-}
-
-gdouble
-camera_get_deg_view_r (void)
-{
-	return camera->deg_view_r;
-}
