@@ -299,3 +299,32 @@ disk_read_string (GIOChannel * ch)
 
 	return name;
 }
+
+/*******************************************/
+
+void
+disk_lzh_extract (const gchar * fullpath_lzh, const gchar *dir)
+{
+	gchar *argv[] = { "lha", "xti", NULL, NULL };
+	GError *err = NULL;
+	gchar *current_dir;
+
+	/* 国土地理院のデータが全国で統一されてない。具体的には、市ごとの圧縮データが
+	 * ディレクトリ付きのものと、そうでないものがある。ということで、中身を全部解凍することにした。
+	 * データ修正後はなおってる可能性があるが、このままで行く。
+	 */
+
+	argv[2] = (gchar *) fullpath_lzh;
+	/*
+	   printf ("%s %s %s\n", argv[0], argv[1], argv[2]);
+	 */
+	current_dir = g_get_current_dir ();
+	chdir (dir);
+	g_spawn_sync (NULL, argv, NULL, G_SPAWN_SEARCH_PATH | G_SPAWN_STDOUT_TO_DEV_NULL, NULL, NULL, NULL, NULL, NULL, &err);
+	if (err != NULL) {
+		g_print ("spawn error::lzh_extract:file:%s:%s:\n", fullpath_lzh, err->message);
+	}
+	chdir (current_dir);
+
+	g_free (current_dir);
+}
