@@ -46,6 +46,7 @@
 #include "saveimage.h"
 #include "mmapthread.h"
 #include "mark.h"
+#include "route.h"
 
 /********************************************/
 
@@ -125,6 +126,9 @@ typedef struct {
 
 static DragState ds;
 
+/* 視野の縦の角度 (度) */
+static gdouble fovy;
+
 typedef struct {
 	GtkWidget *glarea;
 
@@ -201,12 +205,14 @@ thread_func_update (GObject * obj)
 
 	if (n_update_thread == 1) {
 		/*
-		   g_print ("################# update start:%d\n", n_update_thread);
-		 */
+		g_print ("thread_func_update:%d:start\n", n_update_thread);
+		g_print ("################# update start\n");
+		*/
 		mmap_update ();
 		/*
-		   g_print ("################# update finish:%d\n", n_update_thread);
-		 */
+		g_print ("################# update finish\n");
+		g_print ("thread_func_update:%d:end\n", n_update_thread);
+		*/
 	} else {
 	}
 	--n_update_thread;
@@ -264,9 +270,9 @@ create_info (void)
 	if (n == 0) {
 		text_status[0] = '\0';
 	} else if (n == 1) {
-		sprintf (text_status, "Downloading .... ( %d file )", n);
+		sprintf (text_status, "Downloading ....  ( %d file )", n);
 	} else if (n > 1) {
-		sprintf (text_status, "Downloading .... ( %d files )", n);
+		sprintf (text_status, "Downloading ....  ( %d files )", n);
 	} else {
 		/* ありえん */
 		text_status[0] = '\0';
@@ -376,16 +382,39 @@ cross_render (void)
 }
 
 static void
-set_matrix (void)
+set_projection_matrix (void)
 {
-	camera_matrix_prepare (area->w, area->h);
+	gdouble l = 1000.0;			/* 適当に選んだ値 */
+	gdouble near, far;
+	gdouble alt;
+	gdouble radius = mmap_get_world_radius ();
+
+	glMatrixMode (GL_PROJECTION);
+	glLoadIdentity ();
+
+	alt = camera_get_alt ();
+
+	fovy = 360.0 / G_PI * atan ((area->h / 2.0) / l);
+	near = alt * 0.2;
+	far = (radius + alt) * 2.0;
+	/*
+	   far = sqrt ((radius + alt) * (radius + alt) - radius * radius);
+	   g_print("fovy:%.2f  near:%.2f  far:%.2f\n", fovy, near, far);
+	 */
+	gluPerspective (fovy, (gdouble) area->w / area->h, near, far * 2.0);
+}
+
+static void
+set_modelview_matrix (void)
+{
+	camera_matrix_prepare ();
 }
 
 void
 glarea_render_file (void)
 {
-	set_matrix ();
-
+	set_projection_matrix ();
+	set_modelview_matrix ();
 	glClear (GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
 
 	mmap_render ();
@@ -410,13 +439,17 @@ render (void)
 	{
 		glViewport (0, 0, area->w, area->h);
 		glClear (GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
-		set_matrix ();
+		set_projection_matrix ();
+		set_modelview_matrix ();
 
 		mmap_render ();
 
 		glDisable (GL_TEXTURE_2D);
 
 		mark_render ();
+        route_render ();
+        route_render_start_goal ();
+
 #if 0
 		render_test ();			/* 地球の粗い外形 */
 		camera_debug_view_render ();	/* 視野範囲 */
@@ -547,6 +580,7 @@ void
 glarea_force_update_and_render (void)
 {
 	glarea_update ();
+
 	glarea_force_render ();
 }
 
@@ -585,10 +619,9 @@ glarea_mouse_motion_cb (GtkWidget * glarea, GdkEventMotion * event, gpointer use
 				if (l != 0.0) {
 					gdouble dist = camera_get_dist ();
 					gdouble radius = mmap_get_world_radius ();
-					gdouble fovy = camera_get_fovy ();
 
 					/* ar:回転角度 */
-					double ar = l * 360.0 / 2.0 / G_PI * atan (dist * tan (RAD (fovy / 2.0)) / radius) / 8000.0;
+					double ar = l * 360.0 / 2.0 / G_PI * atan (dist / radius * tan (RAD (fovy / 2.0))) / 8000.0;
 					gdouble a = dy / l;
 					gdouble b = dx / l;
 
@@ -704,7 +737,7 @@ glarea_realize_cb (GtkWidget * glarea, gpointer user_data)
 	util_print_bool ("direct rendering enable ", is_direct);
 	if (is_direct == FALSE) {
 		g_print ("############################################\n");
-		g_print ("###     Direct Rendering " "DISABLE" "   ###\n");
+		g_print ("###     Direct Rendering " "DISABLE" "     ###\n");
 		g_print ("############################################\n");
 	}
 
@@ -729,16 +762,24 @@ glarea_realize_cb (GtkWidget * glarea, gpointer user_data)
 		   glCullFace (GL_FRONT);
 		 */
 
+	    glLineWidth (1.0);
+	    glPointSize (10.0);
+	    {
+		    gfloat abc[] = { 0.0, 0.0005, 0.0 };
+
+		    glPointParameterfv (GL_POINT_DISTANCE_ATTENUATION, abc);
+	    }
+
 		glDisable (GL_LIGHTING);
 
 		glEnable (GL_TEXTURE_2D);
 
 		glEnableClientState (GL_VERTEX_ARRAY);
+		glEnableClientState (GL_TEXTURE_COORD_ARRAY);
 		/*
 		   glEnableClientState (GL_COLOR_ARRAY);
 		   glEnableClientState (GL_NORMAL_ARRAY);
 		 */
-		glEnableClientState (GL_TEXTURE_COORD_ARRAY);
 
 		glColorMaterial (GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE);
 		glEnable (GL_COLOR_MATERIAL);
@@ -748,6 +789,13 @@ glarea_realize_cb (GtkWidget * glarea, gpointer user_data)
 		glMatrixMode (GL_MODELVIEW);
 		glLoadIdentity ();
 
+        {
+            gfloat abc[] = { 0.0, 0.0005, 0.0 };
+
+            glPointSize (10.0);
+            glPointParameterfv (GL_POINT_DISTANCE_ATTENUATION, abc);
+        }
+
 		if (gdk_gl_query_gl_extension (vbo) == TRUE) {
 			g_print ("%s ------------ supported\n", vbo);
 			support_vbo = TRUE;
