@@ -22,7 +22,9 @@
 #ifndef __GSI_H__
 #define __GSI_H__
 
-G_BEGIN_DECLS
+#include <gtk/gtk.h>
+
+
 #define W_SECOND 225
 #define H_SECOND 150
 /* 地図のサイズ(単位:pixel) */
@@ -32,6 +34,22 @@ G_BEGIN_DECLS
 /* 地図の右下不要部分のサイズ(単位:pixel) */
 #define W_GREEN 180
 #define H_GREEN 50
+
+/***********/
+
+#include "nmapdata_all.h"
+
+typedef struct {
+	gchar id[3];
+	gchar *name;
+	gchar *value;
+} Data25k;
+
+const gchar *gsi25k_get_data (const gchar * text, Data25k * data25k);
+gfloat *gsi25k_get_curve (const gchar * text, Slp * slp, gint * return_n);
+guint8 gsi25k_hex_to_int (const gchar * text);
+gboolean gsi25k_compare_id(Data25k *data25k, gchar id[]);
+
 /************ 以下はメモ ************/
 /*
  * 最北端：択捉島    北緯45度33分
@@ -39,5 +57,4 @@ G_BEGIN_DECLS
  * 最東端：南鳥島    東経153度59分
  * 最西端：与那国島  東経122度56分
  */
-	G_END_DECLS
 #endif /* __GSI_H__ */
