@@ -30,7 +30,6 @@
 
 #include "light.h"
 #include "glarea.h"
-#include "simplemath.h"
 
 /********************************************/
 
@@ -69,17 +68,19 @@ angle_to_xyz (gdouble lon, gdouble lat)
 	gdouble r;
 	gdouble x, y, z;
 
-	r = cos (RAD (lat));
+	r = cos (2.0 * G_PI * lat / 360.0);
 
-	x = r * cos (RAD (lon));
-	y = r * sin (RAD (lon));
-	z = sin (RAD (lat));
+	x = r * cos (2.0 * G_PI * lon / 360.0);
+	y = r * sin (2.0 * G_PI * lon / 360.0);
+	z = sin (2.0 * G_PI * lat / 360.0);
 
 	light_pos[0] = x;
 	light_pos[1] = y;
 	light_pos[2] = z;
 
+    /*
 	g_print ("angle_to_xyz:x:%f y:%f z:%f\n", light_pos[0], light_pos[1], light_pos[2]);
+    */
 }
 
 static void
@@ -92,11 +93,11 @@ xyz_to_angle (gdouble * lon, gdouble * lat)
 	z = light_pos[2];
 
 	if (x > 0.0) {
-		*lon = DEG (atan (y / x));
+		*lon = 360.0 / (2.0 * G_PI) * atan (y / x);
 	} else {
-		*lon = DEG (atan (y / x)) + 180.0;
+		*lon = 360.0 / (2.0 * G_PI) * atan (y / x) + 180.0;
 	}
-	*lat = DEG (asin (z / 1.0));
+	*lat = 360.0 / (2.0 * G_PI) * asin (z / 1.0);
 
 	g_print ("xyz_to_angle:lon:%f lat:%f\n", *lon, *lat);
 }
@@ -116,7 +117,9 @@ set_lightpos (void)
 
 	angle_to_xyz (lon, lat);
 
+    /*
 	g_print ("set_lightpos:lon:%.0f  lat:%.0f\n", lon, lat);
+    */
 
 	glarea_force_render ();
 }
