@@ -38,8 +38,7 @@
 #include "mmapconfig.h"
 #include "xmlutil.h"
 #include "util.h"
-
-#include "mmapdata.h"
+#include "nmapdata.h"
 
 int
 main (int argc, char *argv[])
@@ -59,19 +58,21 @@ main (int argc, char *argv[])
 
 		mmap_directory_set ();
 		mmap_config_read ();
+       
+        citylist_init();
 		net_init ();
 		xmlutil_type_init ();
 
-		mmapdata_init ();
 		mesh_mmap_init ();
 		color_init ();
 
-
 		mmapthread_init ();
 		camera_init ();
 
 		window_create ();
 
+        nmapdata_selector_init();
+
 		{
 			gchar *path_xml;
 
