@@ -505,7 +505,7 @@ mark_clicked_cb (GtkButton * button, gpointer user_data)
 	alt = 0.0;
 	mark_set_point (mark_no, point_no, lon, lat, alt, "");
 
-    glarea_force_render();
+	glarea_force_render ();
 }
 
 void
@@ -546,7 +546,7 @@ mark_activate_cb (GtkAction * action, gpointer user_data)
 
 	camera_set_position (mp->lon / 3600.0, mp->lat / 3600.0);
 
-	glarea_force_render ();
+	glarea_force_update_and_render ();
 }
 
 static gint uniq_n = 0;
