@@ -223,9 +223,18 @@ make_pointlist_data (void)
 		mp = mark_get_point (mark_current, i);
 
 		util_sec_to_deg_min_sec (mp->lon, &deg, &min, &sec);
-		lon = g_strdup_printf (" E %3d°%2d’%3.1f ", deg, min, sec);
+		if (mp->lon < 0.0) {
+			lon = g_strdup_printf (" W %3d°%2d’%3.1f ", -deg, -min, -sec);
+		} else {
+			lon = g_strdup_printf (" E %3d°%2d’%3.1f ", deg, min, sec);
+		}
+
 		util_sec_to_deg_min_sec (mp->lat, &deg, &min, &sec);
-		lat = g_strdup_printf (" N %3d°%2d’%3.1f ", deg, min, sec);
+		if (mp->lat < 0.0) {
+			lat = g_strdup_printf (" S %3d°%2d’%3.1f ", -deg, -min, -sec);
+		} else {
+			lat = g_strdup_printf (" N %3d°%2d’%3.1f ", deg, min, sec);
+		}
 
 		alt = g_strdup_printf (" %.1f ", mp->alt);
 
@@ -349,10 +358,10 @@ point_list_row_activated_cb (GtkTreeView * treeview, GtkTreePath * path, GtkTree
 
 	mp = mark_get_point (mark_current, point_current);
 
-    if(mp != NULL){
-	    camera_set_position (mp->lon / 3600.0, mp->lat / 3600.0);
-	    glarea_force_update_and_render ();
-    }
+	if (mp != NULL) {
+		camera_set_position (mp->lon / 3600.0, mp->lat / 3600.0);
+		glarea_force_update_and_render ();
+	}
 }
 
 static void
@@ -410,10 +419,10 @@ mark_list_row_activated_cb (GtkTreeView * treeview, GtkTreePath * path, GtkTreeV
 	gtk_tree_model_get (model, &iter, MARK_NO, &no, -1);
 
 	point = mark_get_point (no, 0);
-    if(point != NULL){
-	    camera_set_position (point->lon / 3600.0, point->lat / 3600.0);
-	    glarea_force_update_and_render ();
-    }
+	if (point != NULL) {
+		camera_set_position (point->lon / 3600.0, point->lat / 3600.0);
+		glarea_force_update_and_render ();
+	}
 }
 
 /* 変更をマークとポイントの両方のリストに反映させる */
@@ -429,7 +438,7 @@ change_button_clicked_cb (GtkButton * button, gpointer user_data)
 
 		name = gtk_entry_get_text (GTK_ENTRY (entry_name));
 		if (*name == '\0') {
-			gtk_entry_set_text (GTK_ENTRY (entry_name), "名無し");
+			gtk_entry_set_text (GTK_ENTRY (entry_name), "?????");
 			name = gtk_entry_get_text (GTK_ENTRY (entry_name));
 		}
 
