@@ -26,6 +26,7 @@
 #include "mmap.h"
 #include "util.h"
 #include "xmlutil.h"
+#include "camera.h"
 #include "ww_world.h"
 #include "ww_terrainaccessor.h"
 
@@ -106,12 +107,19 @@ mmap_set_view_mode (MmapViewMode mode)
 
 /*****************************************************/
 
-WwWorld *current_world = NULL;
+static WwWorld *current_world = NULL;
 
 void
 mmap_set_world (const gchar * path_xml)
 {
-	current_world = (WwWorld *) xmlutil_data_build (path_xml);
+
+	if (current_world != NULL) {
+		g_object_unref (current_world);
+	}
+
+	current_world = xmlutil_data_build (path_xml);
+
+	camera_set_dist_direct (ww_world_get_equatorial_radius (current_world) * 3);
 
 	ww_world_create_layer (current_world);
 }
@@ -142,8 +150,6 @@ mmap_get_terrainaccessor (gdouble x0, gdouble y0, gdouble x1, gdouble y1)
 	return ww_world_get_terrainaccessor (current_world, x0, y0, x1, y1);
 }
 
-
-
 void
 mmap_render (void)
 {
