@@ -26,9 +26,10 @@
 
 typedef void (*MmapThreadFunc) (GObject *);
 
-gint mmapthread_get_n_download(void);
+gint mmapthread_get_n_download (void);
 
-void mmapthread_add_download (MmapThreadFunc func, GObject * obj);
+void *mmapthread_download_get (const gchar * uri, gint * return_bytes);
+void mmapthread_add_download2 (const gchar * uri, MmapThreadFunc func, GObject * obj);
 void mmapthread_add_power (MmapThreadFunc func, GObject * obj);
 
 void mmapthread_init (void);
