@@ -96,12 +96,6 @@ net_download_get (CURL * curl, const gchar * uri, gint * return_bytes)
 	curl_easy_setopt (curl, CURLOPT_ERRORBUFFER, &err);
 	curl_easy_setopt (curl, CURLOPT_FAILONERROR, 1);
 
-	/* 名前解決も含めてこの秒以内に終了しなければ、timeout のエラーになるようだ */
-	curl_easy_setopt (curl, CURLOPT_TIMEOUT, 30);
-
-	/* マニュアルにマルチスレッドなプログラムでは 0 以外を指定しろと書いてあった */
-	curl_easy_setopt (curl, CURLOPT_NOSIGNAL, 1);
-
 	DB (curl_easy_setopt (curl, CURLOPT_VERBOSE, 1));
 
 	retval = curl_easy_perform (curl);
