@@ -22,11 +22,14 @@
 #ifndef __NET_H__
 #define __NET_H__
 
+#include <curl/curl.h>
+
 void net_init (void);
-gchar *net_download (const gchar * uri, gint * return_bytes);
-/*
-gchar *net_mmapsearch (const gchar * body);
-*/
+void *net_download (const gchar * uri, gint * return_bytes);
+
+CURL *net_download_set (void);
+void *net_download_get (CURL * curl, const gchar * uri, gint * return_bytes);
+void net_download_cleanup (CURL * curl);
 
 
 #endif /* __NET_H__ */
