@@ -21,8 +21,6 @@
 #include <gtk/gtk.h>
 #include <math.h>
 
-#include "simplemath.h"
-
 /********************************************************************************/
 
 static gdouble
@@ -245,9 +243,31 @@ distance_degree (gdouble lon0, gdouble lat0, gdouble lon1, gdouble lat1)
 {
 	gdouble d;
 
-	d = acos (cos (RAD (lat0)) * cos (RAD (lat1)) * cos (RAD (lon0) - RAD (lon1)) + sin (RAD (lat0)) * sin (RAD (lat1)));
+	gdouble rlon0 = 2.0 * G_PI * lon0 / 360.0;
+	gdouble rlat0 = 2.0 * G_PI * lat0 / 360.0;
+	gdouble rlon1 = 2.0 * G_PI * lon1 / 360.0;
+	gdouble rlat1 = 2.0 * G_PI * lat1 / 360.0;
 
-	return DEG (d);
+	d = acos (cos (rlat0) * cos (rlat1) * cos (rlon0 - rlon1) + sin (rlat0) * sin (rlat1));
+	d *= 360.0 / (2.0 * G_PI);
+
+	return d;
+}
+
+gdouble
+to_deg (gdouble rad)
+{
+	gint a = 360.0 / 2.0 / G_PI;
+
+	return rad * a;
+}
+
+gdouble
+to_rad (gdouble deg)
+{
+	gint a = 2.0 * G_PI / 360.0;
+
+	return deg * a;
 }
 
 /********************************************************************************/
