@@ -45,8 +45,7 @@ gint util_char_to_int (const gchar * s);
 gdouble util_char_to_double (const gchar * s);
 gboolean util_char_to_boolean (const gchar * s);
 
-gboolean util_check_overlap (gdouble x0, gdouble y0, gdouble x1, gdouble y1, gdouble xx0, gdouble yy0, gdouble xx1,
-							 gdouble yy1);
+gboolean util_check_overlap (gdouble x0, gdouble y0, gdouble x1, gdouble y1, gdouble xx0, gdouble yy0, gdouble xx1, gdouble yy1);
 
 void util_tile_get_view (gdouble west, gdouble south, gdouble east, gdouble north, gdouble tile_deg,
 						 gint * x0, gint * y0, gint * x1, gint * y1);
@@ -57,9 +56,10 @@ GdkPixbuf *util_pixbuf_scale_down (const GdkPixbuf * buf, gboolean left, gint si
 void util_sec_to_deg_min_sec (gdouble s_sec, gint * deg, gint * min, gdouble * sec);
 
 
-void gl_error (void);
+gboolean gl_error (void);
 
 gint util_get_cache_size (void);
+void util_print_ref_count (const gchar * text, GObject * obj);
 
 
 #endif /* __UTIL_H__ */
