@@ -25,6 +25,8 @@
 void window_create (void);
 void window_menu_mark_sensitive (gboolean bool);
 void window_menu_saveimage_sensitive (gboolean bool);
+void window_menu_selector_sensitive (gboolean bool);
+void window_menu_route_sensitive (gboolean bool);
 void window_set_mark_submenu (void);
 
 #endif /* __WINDOW_H__ */
