@@ -61,8 +61,7 @@ static void ww_layerset_interface_init (gpointer g_iface, gpointer iface_data);
 /*****************************************************************************/
 
 static void ww_layerset_set_attribute (WwData * data, const gchar ** name, const gchar ** value);
-static void ww_layerset_set_element (WwData * data, const gchar * element0, const gchar * element1,
-									 const gchar * value);
+static void ww_layerset_set_element (WwData * data, const gchar * element0, const gchar * element1, const gchar * value);
 static void ww_layerset_set_parent (WwData * data, WwData * parent);
 static void ww_layerset_set_child (WwData * data, WwData * child);
 
@@ -101,9 +100,9 @@ ww_layerset_get_type (void)
 		type = g_type_register_static (WW_TYPE_OBJECT, "WwLayerset", &info, 0);
 
 		g_type_add_interface_static (type, WW_TYPE_DATA, &ww_data_info);
-        /*
-		g_print ("ww_layerset_get_type\n");
-        */
+		/*
+		   g_print ("ww_layerset_get_type\n");
+		 */
 	}
 
 	return type;
