@@ -33,16 +33,7 @@ G_BEGIN_DECLS
 #define WW_IS_MESH(obj)                 (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WW_TYPE_MESH))
 #define WW_IS_MESH_CLASS(klass)         (G_TYPE_CHECK_CLASS_TYPE ((klass), WW_TYPE_MESH))
 #define WW_MESH_GET_CLASS(obj)          (G_TYPE_INSTANCE_GET_CLASS ((obj), WW_TYPE_MESH, WwMeshClass))
-/* 持っているテクスチャーのどの部分を使っているかをあらわす。t_st は、これによって変わる。 */
 	typedef enum {
-	WW_MESH_TYPE_NORMAL,
-	WW_MESH_TYPE_NORTH_WEST,
-	WW_MESH_TYPE_NORTH_EAST,
-	WW_MESH_TYPE_SOUTH_WEST,
-	WW_MESH_TYPE_SOUTH_EAST,
-} WwMeshType;
-
-typedef enum {
 	WW_MESH_RENDER_TYPE_BOX,
 	WW_MESH_RENDER_TYPE_MESH,
 	WW_MESH_RENDER_TYPE_TEXTURE,
@@ -61,19 +52,13 @@ struct _WwMeshClass {
 
 GType ww_mesh_get_type (void);
 
-WwMesh *ww_mesh_new_simple (gdouble lon_max, gdouble lon_min, gdouble lat_max, gdouble lat_min,
-							gint nx, gint ny, gdouble above_surface, gboolean terrain_mapped);
-WwMesh *ww_mesh_new_with_terrain (gdouble lon_max, gdouble lon_min, gdouble lat_max, gdouble lat_min,
+WwMesh *ww_mesh_new_with_terrain (gdouble x0, gdouble y0, gdouble x1, gdouble y1,
 								  gint nx, gint ny, gdouble above_surface, WwTerrainaccessor * ta);
-WwMesh *ww_mesh_new_copy (gdouble lon_max, gdouble lon_min, gdouble lat_max, gdouble lat_min,
-						  gint nx, gint ny, gdouble above_surface, gboolean terrain_mapped, WwMesh * mesh_parent,
-						  WwMeshType type);
-void ww_mesh_change_type (WwMesh * mesh, WwMeshType type);
-WwMeshType ww_mesh_get_mesh_type (WwMesh * mesh);
+WwMesh *ww_mesh_new_copy (gdouble px0, gdouble py0, gdouble px1, gdouble py1,
+						  gdouble cx0, gdouble cy0, gdouble cx1, gdouble cy1,
+						  gint nx, gint ny, gdouble above_surface, gboolean terrain_mapped, WwMesh * mesh_parent);
 void ww_mesh_render (WwMesh * mesh, WwMeshRenderType type, gboolean is_in_progress, gint color);
-
 void ww_mesh_change_vertical_exaggeration (WwMesh * mesh);
 
-
 G_END_DECLS
 #endif /* __WW_MESH_H__ */
