@@ -504,14 +504,18 @@ ww_placename_update (WwObject * self)
 		gdouble xx0, yy0, xx1, yy1;
 
 		xx0 = wf->west;
-		xx1 = wf->east;
 		yy0 = wf->south;
+		xx1 = wf->east;
 		yy1 = wf->north;
 
 		camera_get_view_narrow (&x0, &y0, &x1, &y1);
 
 		/* ４つの辺それぞれに重なりがあるかどうか見ている */
-		if (camera_check_overlap (yy1, yy0, xx0, xx1) == TRUE) {
+		if ((yy0 >= y0 && yy0 <= y1 && xx0 <= x1 && xx1 >= x0) || (yy1 >= y0 && yy1 <= y1 && xx0 <= x1 && xx1 >= x0) ||
+			(xx0 >= x0 && xx0 <= x1 && yy0 <= y1 && yy1 >= y0) || (xx1 >= x0 && xx1 <= x1 && yy0 <= y1 && yy1 >= y0) ||
+			/* すっぽり入ってるパターン */
+			(xx0 <= x0 && xx1 >= x1 && yy0 <= y0 && yy1 >= y1)) {
+
 			gint j;
 
 			if (wf->wwp_place == NULL) {
@@ -524,21 +528,15 @@ ww_placename_update (WwObject * self)
 			for (j = 0; j < wf->n; ++j) {
 				WwpPlace *wp = &(wf->wwp_place[j]);
 
-				if (x0 < x1) {
-					if (wp->lon > x0 && wp->lon < x1 && wp->lat > y0 && wp->lat < y1) {
-						wp->visible = TRUE;
-					} else {
-						wp->visible = FALSE;
-					}
+				if (wp->lon > x0 && wp->lon < x1 && wp->lat > y0 && wp->lat < y1) {
+					wp->visible = TRUE;
 				} else {
-					if ((wp->lon > x0 || wp->lon < x1) && wp->lat > y0 && wp->lat < y1) {
-						wp->visible = TRUE;
-					} else {
-						wp->visible = FALSE;
-					}
+					wp->visible = FALSE;
 				}
 			}
 
+
+
 		} else {
 			if (wf->wwp_place != NULL) {
 				free_wwp_place (wf->wwp_place, wf->n);
@@ -748,15 +746,6 @@ static WinColor wincolor[] = {
 	{"lightgreen", 0x90, 0xee, 0x90},	/* moon */
 	{"lightgray", 0xd3, 0xd3, 0xd3},	/* moon */
 	{"gold", 0xff, 0xd7, 0x00},	/* moon */
-
-	{"darkslateblue", 0x84, 0x70, 0xff},	/* venus */
-	{"crimson", 0xdc, 0x14, 0x3c},	/* venus */
-	{"hotpink", 0xff, 0x69, 0xb4},	/* venus */
-	{"indianred", 0xcd, 0x5c, 0x5c},	/* venus */
-	{"gainsboro", 0xdc, 0xdc, 0xdc},	/* venus */
-	{"bisque", 0xff, 0xe4, 0xc4},	/* venus */
-	{"beige", 0xf5, 0xf5, 0xdc},	/* venus */
-	{"lightsalmon", 0xff, 0xa0, 0x7a},	/* venus */
 };
 
 static void
