@@ -55,7 +55,7 @@ typedef enum {
 } WwQuadchildState;
 
 typedef enum {
-	WW_QUADCHILD_AREA0,			/* 視点中心からタイル幅の 2.5倍の距離まで。詳細なテクスチャーを使う。 */
+	WW_QUADCHILD_AREA0,			/* 視点中心からタイル幅の 2.5倍の距離まで。詳細なテクスチャーを使う。*/
 	WW_QUADCHILD_AREA1,			/* 視点中心からタイル幅の 6倍の距離まで。テクスチャーのレベルを一つ下げる */
 	WW_QUADCHILD_AREA2,			/* さらに外。視野の外 */
 } WwQuadchildArea;
@@ -193,9 +193,9 @@ ww_quadchild_dispose (GObject * obj)
 {
 	WwQuadchild *self = WW_QUADCHILD (obj);
 	WwQuadchildPrivate *priv = WW_QUADCHILD_GET_PRIVATE (self);
-	/*
-	   g_print ("ww_quadchild_dispose:x:%d y:%d level:%d\n", priv->x, priv->y, priv->level);
-	 */
+    /*
+	g_print ("ww_quadchild_dispose:x:%d y:%d level:%d\n", priv->x, priv->y, priv->level);
+    */
 
 	if (priv->dispose_has_run) {
 		return;
@@ -297,29 +297,30 @@ get_coordinate (WwQuadchild * child, gdouble * west, gdouble * south, gdouble *
 	*north = (priv->y + 1) * priv->tile_deg - 90.0;
 
 	/*
-	   g_print("get_coordinate:l:%d  x:%d y:%d  tile:%.2f %.2f %.2f %.2f %.2f\n", 
-	   priv->level, priv->x, priv->y, priv->tile_deg, *west, *east, *south, *north);
-	 */
+	g_print("get_coordinate:l:%d  x:%d y:%d  tile:%.2f %.2f %.2f %.2f %.2f\n", 
+                                priv->level, priv->x, priv->y, priv->tile_deg, *west, *east, *south, *north);
+	*/
 }
 
 static void
-create_texture_sub (WwQuadchild * child, WwQuadchildArea area)
+create_texture_sub (WwQuadchild * child, WwQuadchild * parent)
 {
 	WwQuadchildPrivate *priv_c = WW_QUADCHILD_GET_PRIVATE (child);
 	WwQuadchildPrivate *priv_p;
 	WwTextureloader *loader;
 	gdouble x0, y0, x1, y1;
 
-	if (area == WW_QUADCHILD_AREA0) {
-		get_coordinate (child, &x0, &y0, &x1, &y1);
-		priv_p = priv_c;
-	} else {
-		get_coordinate (priv_c->parent, &x0, &y0, &x1, &y1);
-		priv_p = WW_QUADCHILD_GET_PRIVATE (priv_c->parent);
-	}
-	/*
-	   g_print ("create_texture_sub:%.2f %.2f %.2f %.2f\n", x0, y0, x1, y1);
-	 */
+    if(parent == NULL){
+	    get_coordinate (child, &x0, &y0, &x1, &y1);
+	    priv_p = WW_QUADCHILD_GET_PRIVATE (child);
+    }else{
+	    get_coordinate (parent, &x0, &y0, &x1, &y1);
+	    priv_p = WW_QUADCHILD_GET_PRIVATE (parent);
+    }
+
+    /*
+	g_print ("create_texture_sub:%.2f %.2f %.2f %.2f\n", x0, y0, x1, y1);
+    */
 
 	loader = ww_textureloader_lookup (priv_p->uri);
 	if (loader == NULL) {
@@ -327,18 +328,15 @@ create_texture_sub (WwQuadchild * child, WwQuadchildArea area)
 
 		ww_texturetile_set_coordinate (texturetile, x0, y0, x1, y1);
 
-		if (priv_c->textureloader != NULL) {
-			g_object_unref (priv_c->textureloader);
-		}
+        if(priv_c->textureloader != NULL){
+            g_object_unref(priv_c->textureloader);
+        }
 		priv_c->textureloader = ww_textureloader_new ();
 		ww_textureloader_set_source (priv_c->textureloader, priv_p->path_dds, priv_p->path_jpg, priv_p->uri, 512, 512);
 		ww_textureloader_set_texture (priv_c->textureloader, WW_TEXTURE (texturetile));
 		ww_textureloader_start (priv_c->textureloader);
 
 	} else {
-		if (priv_c->textureloader != NULL) {
-			g_object_unref (priv_c->textureloader);
-		}
 		g_object_ref (loader);
 		priv_c->textureloader = loader;
 	}
@@ -354,10 +352,11 @@ create_meshst_sub_copy (WwTexture * texture, WwQuadchild * child)
 
 	ww_texturetile_get_coordinate (WW_TEXTURETILE (texture), &tx0, &ty0, &tx1, &ty1);
 	get_coordinate (child, &cx0, &cy0, &cx1, &cy1);
-	/*
-	   g_print ("create_meshst_sub_copy:t::%.2f %.2f %.2f %.2f\n", tx0, ty0, tx1, ty1);
-	   g_print ("                      :c::%.2f %.2f %.2f %.2f\n", cx0, cy0, cx1, cy1);
-	 */
+
+    /*
+	g_print ("create_meshst_sub_copy:t::%.2f %.2f %.2f %.2f\n", tx0, ty0, tx1, ty1);
+	g_print ("                      :c::%.2f %.2f %.2f %.2f\n", cx0, cy0, cx1, cy1);
+    */
 
 	st = ww_meshst_new_complex (SPLIT, SPLIT, tx0, ty0, tx1, ty1, cx0, cy0, cx1, cy1);
 
@@ -379,45 +378,42 @@ create_mesh_sub_copy (WwQuadchild * qc_mesh, WwQuadchild * child)
 
 	get_coordinate (qc_mesh, &mx0, &my0, &mx1, &my1);
 	get_coordinate (child, &cx0, &cy0, &cx1, &cy1);
-	/*
-	   g_print ("create_mesh_sub_copy:m::%.2f %.2f %.2f %.2f\n", mx0, my0, mx1, my1);
-	   g_print ("                    :c::%.2f %.2f %.2f %.2f\n", cx0, cy0, cx1, cy1);
-	 */
+
+    /*
+	g_print ("create_mesh_sub_copy:m::%.2f %.2f %.2f %.2f\n", mx0, my0, mx1, my1);
+	g_print ("                    :c::%.2f %.2f %.2f %.2f\n", cx0, cy0, cx1, cy1);
+    */
+
 	mesh = ww_mesh_new_copy (mx0, my0, mx1, my1, cx0, cy0, cx1, cy1, SPLIT, SPLIT, above_surface, terrain_mapped,
-							 priv_qc_mesh->mesh);
+						  priv_qc_mesh->mesh);
 
 	return mesh;
 }
 
 static WwMeshst *
-create_meshst_sub (WwQuadchild * child, WwQuadchildArea area)
+create_meshst_sub (WwQuadchild * child, WwQuadchild *parent)
 {
 	gdouble px0, py0, px1, py1;
 	gdouble cx0, cy0, cx1, cy1;
 	WwMeshst *meshst = NULL;
 
-	/*
-	   g_print ("create_meshst_sub:L:%d x:%d y:%d\n", priv_c->level, priv_c->x, priv_c->y);
-	 */
+    /*
+	g_print ("create_meshst_sub:L:%d x:%d y:%d\n", priv_c->level, priv_c->x, priv_c->y);
+    */
 
 	get_coordinate (child, &cx0, &cy0, &cx1, &cy1);
-
-	if (area == WW_QUADCHILD_AREA0) {
-		px0 = cx0;
-		py0 = cy0;
-		px1 = cx1;
-		py1 = cy1;
-	} else {
-		WwQuadchildPrivate *priv = WW_QUADCHILD_GET_PRIVATE (child);
-		if (priv->parent == NULL) {
-			return NULL;
-		}
-		get_coordinate (priv->parent, &px0, &py0, &px1, &py1);
-	}
+    if(parent == NULL){
+        px0 = cx0;
+        py0 = cy0;
+        px1 = cx1;
+        py1 = cy1;
+    }else{
+	    get_coordinate (parent, &px0, &py0, &px1, &py1);
+    }
 
 	meshst = ww_meshst_new_complex (SPLIT, SPLIT, px0, py0, px1, py1, cx0, cy0, cx1, cy1);
 
-	return meshst;
+    return meshst;
 }
 
 static void
@@ -428,9 +424,10 @@ create_mesh_sub (WwQuadchild * child)
 	gdouble x0, y0, x1, y1;
 	gdouble above_surface = ww_quadtile_get_above_surface (tile);
 	gboolean terrain_mapped = ww_quadtile_get_terrain_mapped (tile);
-	/*
-	   g_print ("create_mesh_sub:L:%d x:%d y:%d\n", priv->level, priv->x, priv->y);
-	 */
+
+    /*
+	g_print ("create_mesh_sub:L:%d x:%d y:%d\n", priv->level, priv->x, priv->y);
+    */
 
 	get_coordinate (child, &x0, &y0, &x1, &y1);
 
@@ -517,6 +514,7 @@ ww_quadchild_clear_flag (WwQuadchild * child)
 	ww_quadchild_clear_flag (priv->south_east);
 }
 
+
 static gboolean
 is_in_view (gint x, gint y, gdouble tile_deg)
 {
@@ -576,9 +574,10 @@ get_upper_level_texture_and_mesh (WwQuadchild * qc)
 	}
 
 	priv = WW_QUADCHILD_GET_PRIVATE (qc);
-	/*
-	   g_print ("get_upper_level_texture_and_mesh:%d\n", priv->level);
-	 */
+
+    /*
+	g_print ("get_upper_level_texture_and_mesh:%d\n", priv->level);
+    */
 
 	if (priv->texture != NULL && ww_texture_is_ok (priv->texture) == TRUE) {
 		return qc;
@@ -617,64 +616,50 @@ check_area (WwQuadchild * child)
 	WwQuadchildPrivate *priv = WW_QUADCHILD_GET_PRIVATE (child);
 	gdouble lon_camera, lat_camera;
 	gdouble lon_qc, lat_qc;
-
 	gdouble l;
-	gdouble dd;
 
-	lon_camera = camera_get_lon_target ();
-	lat_camera = camera_get_lat_target ();
+	lon_camera = camera_get_lon ();
+	lat_camera = camera_get_lat ();
 
 	lon_qc = (priv->x + 0.5) * priv->tile_deg - 180.0;
 	lat_qc = (priv->y + 0.5) * priv->tile_deg - 90.0;
 
-	dd = camera_get_deg_view_r () / 2.0;	/* 見えている範囲の半分 */
-	{
-		WwQuadtile *tile = priv->quadtile;
-		gdouble level_zero_tile_deg = ww_quadtile_get_level_zero_tile_size_degrees (tile);
-		gint n_level = ww_quadtile_get_number_levels (tile);
-		gdouble deg = level_zero_tile_deg / pow (2.0, n_level);
-
-		if (dd < deg * 3.0) {
-			dd = deg * 3.0;
-		}
-	}
-
-	/*
-	   g_print ("check_area:x %d y:%d     tiledeg:%.2f\n", priv->x, priv->y, priv->tile_deg);
-	   g_print ("check_area:camera:%.2f %.2f   tile:%.2f %.2f\n", lon_camera, lat_camera, lon_qc, lat_qc);
-	 */
+    /*
+	g_print ("check_area:x %d y:%d     tiledeg:%.2f\n", priv->x, priv->y, priv->tile_deg);
+	g_print ("check_area:camera:%.2f %.2f   tile:%.2f %.2f\n", lon_camera, lat_camera, lon_qc, lat_qc);
+    */
 	l = distance_degree (lon_camera, lat_camera, lon_qc, lat_qc);
 
-	if (l < dd * 1.5) {
-		/*
-		   g_print ("check_area: area0 :l:%.2f < %.2f\n", l, dd);
-		 */
+	if (l > priv->tile_deg * 6.0) {
+        /*
+		g_print ("check_area: area2 :l:%.2f > 6 * %.2f\n", l, priv->tile_deg);
+        */
 
-		return WW_QUADCHILD_AREA0;
+		return WW_QUADCHILD_AREA2;
 
-	} else if (l < dd * 4.0) {
-		/*
-		   g_print ("check_area: area1 :l:%.2f < 2 * %.2f\n", l, dd);
-		 */
+	} else if (l > priv->tile_deg * 2.5) {
+        /*
+		g_print ("check_area: area1 :l:%.2f > 3 * %.2f\n", l, priv->tile_deg);
+        */
 
 		return WW_QUADCHILD_AREA1;
 
 	} else {
-		/*
-		   g_print ("check_area: area2 :l:%.2f > 2 * %.2f\n", l, dd);
-		 */
+        /*
+		g_print ("check_area: area0 :l:%.2f < 3 * %.2f\n", l, priv->tile_deg);
+        */
 
-		return WW_QUADCHILD_AREA2;
+		return WW_QUADCHILD_AREA0;
 	}
 }
 
 void
-check_textureloader (WwQuadchild * child)
+check_textureloader(WwQuadchild *child)
 {
 	WwQuadchildPrivate *priv = WW_QUADCHILD_GET_PRIVATE (child);
 
 	if (priv->textureloader != NULL) {
-		WwTexture *texture;
+	    WwTexture *texture;
 
 		texture = ww_textureloader_get_texture (priv->textureloader);
 		if (texture != NULL) {
@@ -689,12 +674,12 @@ check_textureloader (WwQuadchild * child)
 				g_object_unref (priv->textureloader);
 				priv->textureloader = NULL;
 
-				if (priv->state == WW_QUADCHILD_STATE_ORIG0) {
-					ww_meshst_change_simple (priv->meshst);
-				} else {
-					g_object_unref (priv->meshst);
-					priv->meshst = create_meshst_sub (child, WW_QUADCHILD_AREA1);
-				}
+                if(priv->state == WW_QUADCHILD_STATE_ORIG0){
+				    ww_meshst_change_simple (priv->meshst);
+                }else{
+                    g_object_unref(priv->meshst);
+                    priv->meshst = create_meshst_sub (child, priv->parent);
+                }
 
 			}
 			g_mutex_unlock (priv->mutex_texture_and_mesh);
@@ -705,7 +690,7 @@ check_textureloader (WwQuadchild * child)
 }
 
 void
-check_meshloader (WwQuadchild * child)
+check_meshloader(WwQuadchild *child)
 {
 	WwQuadchildPrivate *priv = WW_QUADCHILD_GET_PRIVATE (child);
 
@@ -761,7 +746,7 @@ ww_quadchild_update (WwQuadchild * child, gint level)
 	   }
 	 */
 
-	/* ここにくるということは範囲内なので必要 */
+    /* ここにくるということは範囲内なので必要 */
 	priv->need = TRUE;
 
 	if (priv->level < level) {
@@ -782,8 +767,8 @@ ww_quadchild_update (WwQuadchild * child, gint level)
 
 		if (area == WW_QUADCHILD_AREA0) {
 			if (priv->state == WW_QUADCHILD_STATE_ORIG0) {
-				check_textureloader (child);
-				check_meshloader (child);
+                check_textureloader(child);
+                check_meshloader(child);
 
 				/* texture と mesh のどちらかが完成していなかったら、子レベルを消さないように必要フラグを付ける */
 				if (priv->texture == NULL || priv->mesh == NULL) {
@@ -791,38 +776,40 @@ ww_quadchild_update (WwQuadchild * child, gint level)
 				}
 
 			} else if (priv->state == WW_QUADCHILD_STATE_ORIG1) {
-				check_textureloader (child);
-				check_meshloader (child);
+                check_textureloader(child);
+                check_meshloader(child);
 
-				create_texture_sub (child, WW_QUADCHILD_AREA0);
-
-				priv->state = WW_QUADCHILD_STATE_ORIG0;
+				create_texture_sub (child, NULL);
 
 				glarea_force_update_and_render ();
 
+				priv->state = WW_QUADCHILD_STATE_ORIG0;
+
 			} else if (priv->state == WW_QUADCHILD_STATE_TEMP) {
-				create_texture_sub (child, WW_QUADCHILD_AREA0);
+				create_texture_sub (child, NULL);
 				create_mesh_sub (child);
 
-				priv->state = WW_QUADCHILD_STATE_ORIG0;
-
 				glarea_force_update_and_render ();
 
+				priv->state = WW_QUADCHILD_STATE_ORIG0;
+
 			} else if (priv->state == WW_QUADCHILD_STATE_INIT) {
-				/* mesh と texture を持つ quadchild。ここの mesh を使う。ここの texture はさらに上の階層のものの可能性もある。 */
-				WwQuadchild *qc_mesh = get_upper_level_texture_and_mesh (priv->parent);
+				WwQuadchild *qc_mesh;
+
+				/* mesh と texture を持つ quadchild。ここの mesh を使う。ここの texture はさらに上の階層のものの可能性もある。*/
+				qc_mesh = get_upper_level_texture_and_mesh (priv->parent);
 
 				child_flag_set (child, TRUE);
 
 				if (qc_mesh == NULL) {
-					create_texture_sub (child, WW_QUADCHILD_AREA0);
+					create_texture_sub (child, NULL);
 
 					g_mutex_lock (priv->mutex_texture_and_mesh);
 					{
-						if (priv->meshst != NULL) {
-							g_object_unref (priv->meshst);
-						}
-						priv->meshst = create_meshst_sub (child, WW_QUADCHILD_AREA0);
+                        if(priv->meshst != NULL){
+                            g_object_unref(priv->meshst);
+                        }
+					    priv->meshst = create_meshst_sub (child, NULL);
 					}
 					g_mutex_unlock (priv->mutex_texture_and_mesh);
 
@@ -848,63 +835,53 @@ ww_quadchild_update (WwQuadchild * child, gint level)
 
 		} else if (area == WW_QUADCHILD_AREA1) {
 			if (priv->state == WW_QUADCHILD_STATE_ORIG0) {
-				check_textureloader (child);
-				check_meshloader (child);
+                check_textureloader(child);
+                check_meshloader(child);
 
-				if (priv->parent == NULL) {
-					priv->state = WW_QUADCHILD_STATE_INIT;
-				} else {
-					create_texture_sub (child, WW_QUADCHILD_AREA1);
-					priv->state = WW_QUADCHILD_STATE_ORIG1;
-					glarea_force_update_and_render ();
-				}
+				create_texture_sub (child, priv->parent);
 
-			} else if (priv->state == WW_QUADCHILD_STATE_ORIG1) {
-				check_textureloader (child);
-				check_meshloader (child);
+				glarea_force_update_and_render ();
+
+				priv->state = WW_QUADCHILD_STATE_ORIG1;
+
+			}else if (priv->state == WW_QUADCHILD_STATE_ORIG1) {
+                check_textureloader(child);
+                check_meshloader(child);
 
 				/* texture と mesh のどちらかが完成していなかったら、子レベルを消さないように必要フラグを付ける */
 				if (priv->texture == NULL || priv->mesh == NULL) {
 					child_flag_set (child, TRUE);
 				}
 
-			} else if (priv->state == WW_QUADCHILD_STATE_TEMP) {
-				if (priv->parent == NULL) {
-					priv->state = WW_QUADCHILD_STATE_INIT;
-				} else {
-					create_texture_sub (child, WW_QUADCHILD_AREA1);
-					create_mesh_sub (child);
-					priv->state = WW_QUADCHILD_STATE_ORIG1;
-					glarea_force_update_and_render ();
-				}
+			}else if (priv->state == WW_QUADCHILD_STATE_TEMP) {
+				create_texture_sub (child, priv->parent);
+				create_mesh_sub (child);
 
-			} else if (priv->state == WW_QUADCHILD_STATE_INIT) {
+				glarea_force_update_and_render ();
+
+				priv->state = WW_QUADCHILD_STATE_ORIG1;
+
+			}else if (priv->state == WW_QUADCHILD_STATE_INIT) {
 				WwQuadchild *qc_mesh;
 
-				/* mesh と texture を持つ quadchild。ここの mesh を使う。ここの texture はさらに上の階層のものの可能性もある。 */
+				/* mesh と texture を持つ quadchild。ここの mesh を使う。ここの texture はさらに上の階層のものの可能性もある。*/
 				qc_mesh = get_upper_level_texture_and_mesh (priv->parent);
 
 				child_flag_set (child, TRUE);
 
 				if (qc_mesh == NULL) {
-					if (priv->parent == NULL) {
-						priv->state = WW_QUADCHILD_STATE_INIT;
-					} else {
-						create_texture_sub (child, WW_QUADCHILD_AREA1);
-						g_mutex_lock (priv->mutex_texture_and_mesh);
-						{
-							if (priv->meshst != NULL) {
-								g_object_unref (priv->meshst);
-							}
-							priv->meshst = create_meshst_sub (child, WW_QUADCHILD_AREA0);
-						}
-						g_mutex_unlock (priv->mutex_texture_and_mesh);
-						create_mesh_sub (child);
-
-						priv->state = WW_QUADCHILD_STATE_ORIG1;
-
-						glarea_force_update_and_render ();
+					create_texture_sub (child, priv->parent);
+					g_mutex_lock (priv->mutex_texture_and_mesh);
+					{
+                        if(priv->meshst != NULL){
+                            g_object_unref(priv->meshst);
+                        }
+					    priv->meshst = create_meshst_sub (child, NULL);
 					}
+					g_mutex_unlock (priv->mutex_texture_and_mesh);
+					create_mesh_sub (child);
+
+					priv->state = WW_QUADCHILD_STATE_ORIG1;
 
 				} else {
 					WwQuadchildPrivate *priv_qc_mesh = WW_QUADCHILD_GET_PRIVATE (qc_mesh);
@@ -918,10 +895,9 @@ ww_quadchild_update (WwQuadchild * child, gint level)
 					g_mutex_unlock (priv->mutex_texture_and_mesh);
 
 					priv->state = WW_QUADCHILD_STATE_TEMP;
-
-					glarea_force_update_and_render ();
 				}
-			}
+				glarea_force_update_and_render ();
+            }
 
 		} else if (area == WW_QUADCHILD_AREA2) {
 			priv->state = WW_QUADCHILD_STATE_INIT;
@@ -1003,17 +979,17 @@ ww_quadchild_remove_child (WwQuadchild * child, gint level)
 		g_mutex_unlock (priv->mutex_texture_and_mesh);
 	} else if (priv->level == level) {
 		/* 目標レベルそのものは、範囲外のものの texture と mesh を削除。 */
-		if (priv->state == WW_QUADCHILD_STATE_INIT) {
-			g_mutex_lock (priv->mutex_texture_and_mesh);
-			{
-				if (priv->textureloader != NULL) {
-					g_object_unref (priv->textureloader);
-					priv->textureloader = NULL;
-				}
-				if (priv->meshloader != NULL) {
-					g_object_unref (priv->meshloader);
-					priv->meshloader = NULL;
-				}
+        if(priv->state == WW_QUADCHILD_STATE_INIT){
+		    g_mutex_lock (priv->mutex_texture_and_mesh);
+		    {
+			    if (priv->textureloader != NULL) {
+				    g_object_unref (priv->textureloader);
+				    priv->textureloader = NULL;
+			    }
+			    if (priv->meshloader != NULL) {
+				    g_object_unref (priv->meshloader);
+				    priv->meshloader = NULL;
+			    }
 				if (priv->texture != NULL) {
 					g_object_unref (priv->texture);
 					priv->texture = NULL;
@@ -1026,10 +1002,10 @@ ww_quadchild_remove_child (WwQuadchild * child, gint level)
 					g_object_unref (priv->mesh);
 					priv->mesh = NULL;
 				}
-			}
-			g_mutex_unlock (priv->mutex_texture_and_mesh);
+		    }
+		    g_mutex_unlock (priv->mutex_texture_and_mesh);
 
-		}
+        }
 	} else {
 		/* textureloader と meshloader は破棄 */
 		g_mutex_lock (priv->mutex_texture_and_mesh);
@@ -1125,32 +1101,32 @@ ww_quadchild_render (WwQuadchild * child)
 
 	g_mutex_lock (priv->mutex_texture_and_mesh);
 	{
-		if (priv->mesh == NULL) {
+		if (priv->texture == NULL || priv->mesh == NULL) {
 			;
 		} else {
 			gboolean textured;
 			gboolean is_in_progress = TRUE;
-			gint area;
+            gint area;
 
 			textured = ww_texture_bind (priv->texture);
 
-			if (priv->state == WW_QUADCHILD_STATE_ORIG0 && priv->texture != NULL) {
+			if (priv->state == WW_QUADCHILD_STATE_ORIG0) {
 				is_in_progress = FALSE;
-			} else if (priv->state == WW_QUADCHILD_STATE_ORIG1 && priv->texture != NULL) {
+			} else if (priv->state == WW_QUADCHILD_STATE_ORIG1) {
 				is_in_progress = FALSE;
-			} else {
+			} else if (priv->state == WW_QUADCHILD_STATE_TEMP) {
 				is_in_progress = TRUE;
 			}
 
-			if (priv->state == WW_QUADCHILD_STATE_ORIG0) {
-				area = 0;
-			} else if (priv->state == WW_QUADCHILD_STATE_ORIG1) {
-				area = 1;
-			} else if (priv->state == WW_QUADCHILD_STATE_TEMP) {
-				area = 2;
-			} else {
-				area = 3;
-			}
+            if(priv->state == WW_QUADCHILD_STATE_ORIG0){
+                area = 0;
+            }else if(priv->state == WW_QUADCHILD_STATE_ORIG1){
+                area = 1;
+            }else if(priv->state == WW_QUADCHILD_STATE_TEMP){
+                area = 2;
+            }else{
+                area = 3;
+            }
 
 			if (textured == TRUE) {
 				ww_meshst_bind (priv->meshst);
