@@ -36,7 +36,6 @@
 #include "ww_quadchild.h"
 #include "util.h"
 #include "camera.h"
-#include "simplemath.h"
 
 typedef struct _WwQuadtilePrivate WwQuadtilePrivate;
 struct _WwQuadtilePrivate {
@@ -305,17 +304,17 @@ get_level (gdouble level_zero_tile_deg, gint number_levels)
 	gint i;
 	gdouble l;
 	gdouble dist = camera_get_dist_target ();
-	gdouble radius = mmap_get_world_radius ();
 
 	/* 視野角55度の時の注視点付近での視野範囲の距離 */
-	l = 2.0 * dist * tan (RAD (55.0 / 2.0));
+	l = 2.0 * dist * tan (2.0 * G_PI * 55.0 / 2.0 / 360.0);
 
 	for (i = 0; i < number_levels; ++i) {
 		gdouble ll;
 		gdouble deg = level_zero_tile_deg / pow (2.0, i);
+		gdouble radius = mmap_get_world_radius ();
 
 		/* 今のレベルでのタイル１枚の辺の距離 */
-		ll = 2.0 * radius * tan (RAD (deg / 2.0));
+		ll = 2.0 * radius * tan (2.0 * G_PI * deg / 2.0 / 360.0);
 
 		/*
 		   g_print("get_level:dist:%.2f   l:%.2f  ll:%.2f\n", dist, l, ll);
@@ -332,7 +331,7 @@ get_level (gdouble level_zero_tile_deg, gint number_levels)
 			return i;
 		}
 	}
-	return number_levels - 1;	/* もっとも詳細なレベル */
+	return number_levels - 1;
 }
 
 static void
@@ -345,7 +344,9 @@ remove_child (WwQuadtile * tile, gint level)
 	 */
 	for (sl = priv->sl_child; sl != NULL; sl = sl->next) {
 		WwQuadchild *child = sl->data;
-
+		/*  
+		   util_print_ref_count ("remove_child: ref_count:%d\n", child);
+		 */
 		ww_quadchild_remove_child (child, level);
 	}
 }
@@ -360,14 +361,19 @@ remove_top_level (WwQuadtile * tile, gint level)
 	/*
 	   g_print ("remove_top_level\n");
 	 */
-
 	for (sl = priv->sl_child, prev = NULL; sl != NULL; sl = next) {
 		WwQuadchild *child = sl->data;
 
 		next = sl->next;
+		/*
+		   util_print_ref_count ("remove_top_level: ref_count:%d\n", child);
+		 */
 
 		if (ww_quadchild_get_need_flag (child) == FALSE || level < 0) {
 			g_object_unref (child);
+			/*
+			   util_print_ref_count ("               removed: ref_count:%d\n", child);
+			 */
 
 			if (prev == NULL) {
 				priv->sl_child = next;
@@ -418,20 +424,16 @@ update_top_level (WwQuadtile * tile)
 	gint i, j;
 	gint x0, y0;
 	gint x1, y1;
-	gdouble north;
-	gdouble south;
-	gdouble west;
-	gdouble east;
+	gdouble north, south, west, east;
 	gdouble tile_deg = priv->level_zero_tile_size_degrees;
 
 	camera_get_view_wide (&west, &south, &east, &north);	/* 見える範囲。要修正。極付近は大間違い。 */
 
 	util_tile_get_view (west, south, east, north, tile_deg, &x0, &y0, &x1, &y1);
-
 	/*
-	   g_print ("update_top_level:w:%.2f e:%.2f s:%.2f n:%.2f\n", west, east, south, north);
-	   g_print ("update_top_level:(x0,y0)-(x1,y1):(%d,%d)-(%d,%d)\n", x0, y0, x1, y1);
-	 */
+	g_print ("update_top_level:w:%.2f e:%.2f s:%.2f n:%.2f\n", west, east, south, north);
+	g_print ("update_top_level:(x0,y0)-(x1,y1):(%d,%d)-(%d,%d)\n", x0, y0, x1, y1);
+	*/
 
 	/* 範囲が東経180度をまたぐ時は、下の for で使えないので下駄をかます */
 	if (x0 > x1) {
@@ -497,34 +499,34 @@ ww_quadtile_update (WwObject * self)
 		return;
 	}
 
-	if (self->is_on == FALSE) {
-		return;
-	}
-
 	tile = WW_QUADTILE (self);
 	priv = WW_QUADTILE_GET_PRIVATE (tile);
 
 	level = get_level (priv->level_zero_tile_size_degrees, priv->number_levels);
-	/*
-	   g_print ("ww_quadtile_update:level(target level:%d):%s\n", level, self->name);
-	 */
+
+    /*
+	g_print ("ww_quadtile_update:level(target level:%d):%s\n", level, self->name);
+    */
 
 	ww_quadtile_clear_flag (tile);
 
-	/*
-	   g_print("wwquadtile_updat:%.2f %.2f %.2f %.2f\n", priv->west, priv->south, priv->east, priv->north);
-	 */
-	if (level >= 0 && camera_check_overlap (priv->north, priv->south, priv->west, priv->east) == TRUE) {
-		/* レベル0 だけを作りなおす。無いものを作り、不要なものの need フラグを落とす。削除はしない。 */
-		update_top_level (tile);
-	}
+	if (self->is_on == TRUE) {
+	    /*
+	    g_print("wwquadtile_updat:%.2f %.2f %.2f %.2f\n", priv->west, priv->south, priv->east, priv->north);
+	    */
+	    if (level >= 0 && camera_check_overlap (priv->north, priv->south, priv->west, priv->east) == TRUE) {
+		    /* レベル0 だけを作りなおす。無いものを作り、不要なものの need フラグを落とす。削除はしない。 */
+		    update_top_level (tile);
+	    }
+    }
 	g_mutex_lock (priv->mutex_sl_child);
 	remove_top_level (tile, level);	/* need_flag の落ちたトップレベルの child を削除する。 */
 	g_mutex_unlock (priv->mutex_sl_child);
 
-	/* level1 以上の need_flag はここで付け直す */
-	update_child (tile, level);
-
+	if (self->is_on == TRUE) {
+	    /* level1 以上の need_flag はここで付け直す */
+	    update_child (tile, level);
+    }
 	g_mutex_lock (priv->mutex_sl_child);
 	/* need_flag の落ちた child を削除するとともに、不要になったテクスチャーとメッシュを削除する。 */
 	remove_child (tile, level);
