@@ -47,8 +47,9 @@
 #include "mmapthread.h"
 #include "disk.h"
 #include "color.h"
-#include "mmapdata.h"
+#include "nmapdata.h"
 #include "light.h"
+#include "ww_gsiloader.h"
 
 typedef struct _WwSmapPrivate WwSmapPrivate;
 
@@ -87,6 +88,8 @@ struct _WwSmapPrivate {
 	WwTexture *texture;
 	WwTextureloader *textureloader;
 
+    WwGsiloader *gsiloader;
+
 	WwMmap *parent;
 
 	gboolean is_detached;		/* 描画対象から外されたら（ww_mmap から外されたら）TRUE */
@@ -190,6 +193,8 @@ ww_smap_init (WwSmap * self)
 	priv->texture = NULL;
 	priv->textureloader = NULL;
 
+	priv->gsiloader = NULL;
+
 	priv->parent = NULL;
 
 	priv->is_detached = FALSE;
@@ -221,6 +226,11 @@ ww_smap_dispose (GObject * obj)
 		priv->textureloader = NULL;
 	}
 
+	if (priv->gsiloader != NULL) {
+		g_object_unref (priv->gsiloader);
+		priv->gsiloader = NULL;
+	}
+
 	G_OBJECT_CLASS (parent_class)->dispose (obj);
 }
 
@@ -266,9 +276,9 @@ ww_smap_new (void)
 	GObject *object;
 
 	object = g_object_new (WW_TYPE_SMAP, NULL);
-	/*
-	   g_print ("ww_smap_new:o:%p\n", object);
-	 */
+
+	g_print ("ww_smap_new:o:%p\n", object);
+
 	return WW_SMAP (object);
 }
 
@@ -283,7 +293,9 @@ smap_image_manipulate_func (GObject * obj, GdkPixbuf * pixbuf)
 	gint texture_size = glarea_get_max_texture_size ();
 	gboolean left;
 
+    /*
 	g_print ("smap_image_manipulate_func:%s\n", priv->name);
+    */
 
 	if (priv->name[7] == '0') {
 		left = TRUE;
@@ -328,13 +340,14 @@ ww_smap_new_with_name (WwMmap * parent, gint lon_sec, gint lat_sec, const gchar
 	priv->y0 = lat_sec + 1;
 	priv->y1 = priv->y0 + H_SECOND;
 
+	g_print ("ww_smap_new_with_name:%d %d %s\n", lon_sec, lat_sec, name);
 	/*
-	   g_print ("ww_smap_new_with_name:%d %d %s\n", lon_sec, lat_sec, name);
 	   g_print ("ww_smap_new_with_name:%d %d %d %d\n", priv->x0, priv->y0, priv->x1, priv->y1);
 	 */
 
 	path_v = g_strconcat (mmap_dir_gsi_vn, priv->name, ".v", NULL);
 	path_n = g_strconcat (mmap_dir_gsi_vn, priv->name, ".n", NULL);
+
 	/*
 	   multi = mmap_get_vertical_exaggeration ();
 	 */
@@ -348,12 +361,19 @@ ww_smap_new_with_name (WwMmap * parent, gint lon_sec, gint lat_sec, const gchar
 		priv->c = mesh_mmap_c_init (priv->nx, priv->ny);
 		mesh_mmap_c_calc (priv->c, priv->v_deg, priv->nv);
 	} else {
+        GSList *sl_city = NULL;
+
 		priv->v_deg = mesh_mmap_v_deg_init (priv->x0, priv->y0, priv->nx, priv->ny);
 		priv->v_xyz = mesh_mmap_v_xyz_init (priv->v_deg, priv->nx, priv->ny, multi);
 		priv->n = mesh_mmap_n_init (priv->v_xyz, priv->nx, priv->ny);
 		priv->c = mesh_mmap_c_init (priv->nx, priv->ny);
 
-		mmapdata_prepare (smap);
+	    sl_city = citylist_lookup(priv->x0, priv->y0, priv->x1, priv->y1);
+
+        priv->gsiloader = ww_gsiloader_new();
+        ww_gsiloader_set_owner(priv->gsiloader, (GObject *)smap);
+        ww_gsiloader_add_source_list(priv->gsiloader, sl_city);
+        ww_gsiloader_start(priv->gsiloader);
 	}
 	g_free (path_v);
 	g_free (path_n);
@@ -416,13 +436,10 @@ ww_smap_update (WwSmap * smap)
 
 			g_object_unref (priv->textureloader);
 			priv->textureloader = NULL;
-
-			glarea_force_update_and_render ();
 		}
 	}
 }
 
-
 void
 ww_smap_render (WwSmap * smap)
 {
@@ -560,7 +577,9 @@ ww_smap_color_set (WwSmap * smap)
 {
 	WwSmapPrivate *priv = WW_SMAP_GET_PRIVATE (smap);
 
+    /*
 	g_print ("ww_smap_color_set\n");
+    */
 
 	mesh_mmap_c_calc (priv->c, priv->v_deg, priv->nv);
 
@@ -618,7 +637,7 @@ set_p (gdouble lon, gdouble lat, gdouble * p)
 	gdouble x, y, z;
 	gdouble alt;
 
-	alt = mmapdata_get_alt (lon, lat);
+	alt = city_get_alt (lon, lat);
 
 	mmap_deg_to_xyz (lon, lat, alt, &x, &y, &z);
 
@@ -638,7 +657,9 @@ n_calc (WwSmap * smap)
 	gint w = priv->nx + 1;		/* 横の頂点数 */
 	gint h = priv->ny + 1;		/* 縦の頂点数 */
 
+    /*
 	g_print ("n_calc:\n");
+    */
 
 	for (j = 0; j < h; ++j) {
 		for (i = 0; i < w; ++i) {
@@ -761,7 +782,9 @@ ww_smap_vcn_calc (WwSmap * smap)
 	gint i;
 	gdouble multi = mmap_get_vertical_exaggeration ();
 
+    /*
 	g_print ("ww_smap_vcn_calc:\n");
+    */
 
 	for (i = 0; i < priv->nv; ++i) {
 		gint k;
@@ -774,7 +797,7 @@ ww_smap_vcn_calc (WwSmap * smap)
 		lon = *(priv->v_deg + k + 0);
 		lat = *(priv->v_deg + k + 1);
 
-		alt = mmapdata_get_alt (lon, lat);
+		alt = multi * city_get_alt (lon, lat);
 
 		*(priv->v_deg + k + 2) = alt;
 
@@ -798,8 +821,8 @@ ww_smap_vcn_calc (WwSmap * smap)
 			*(priv->c + k + 2) = (gdouble) b / 0xff;
 		}
 		/*
-		   g_print("ww_smap_vcn_calc:alt:%.2f c:%.2f %.2f %.2f\n", alt, *(priv->c + k + 0), *(priv->c + k + 1), *(priv->c + k + 2));
-		 */
+		g_print("ww_smap_vcn_calc:alt:%.2f c:%.2f %.2f %.2f\n", alt, *(priv->c + k + 0), *(priv->c + k + 1), *(priv->c + k + 2));
+		*/
 	}
 	n_calc (smap);
 
@@ -821,15 +844,22 @@ ww_smap_is_detached_from_render_list (WwSmap * smap)
 	WwSmapPrivate *priv = WW_SMAP_GET_PRIVATE (smap);
 
 	priv->is_detached = TRUE;
-
 }
 
 void
 ww_smap_change_vertical_exaggeration (WwSmap * smap)
 {
-	WwSmapPrivate *priv = WW_SMAP_GET_PRIVATE (smap);
+	WwSmapPrivate *priv;
 	gdouble multi;
 
+	if (smap == NULL) {
+		return;
+	}
+
+	priv = WW_SMAP_GET_PRIVATE (smap);
+	/*
+	g_print ("ww_smap_change_vertical_exaggeration:\n");
+	*/
 	multi = mmap_get_vertical_exaggeration ();
 
 	mesh_mmap_v_xyz_change (priv->v_deg, priv->v_xyz, priv->nx, priv->ny, multi);
