@@ -47,7 +47,6 @@ typedef struct {
 	gint16 *tile;
 } OneTile;
 
-
 static void onetile_free (WwTerrainaccessor * ta);
 
 /********************************/
@@ -92,8 +91,7 @@ static void ww_terrainaccessor_interface_init (gpointer g_iface, gpointer iface_
 /*****************************************************************************/
 
 static void ww_terrainaccessor_set_attribute (WwData * data, const gchar ** name, const gchar ** value);
-static void ww_terrainaccessor_set_element (WwData * data, const gchar * element0, const gchar * element1,
-											const gchar * value);
+static void ww_terrainaccessor_set_element (WwData * data, const gchar * element0, const gchar * element1, const gchar * value);
 static void ww_terrainaccessor_set_parent (WwData * data, WwData * parent);
 static void ww_terrainaccessor_set_child (WwData * data, WwData * child);
 
@@ -182,15 +180,17 @@ ww_terrainaccessor_dispose (GObject * obj)
 {
 	WwTerrainaccessor *self = WW_TERRAINACCESSOR (obj);
 	WwTerrainaccessorPrivate *priv = WW_TERRAINACCESSOR_GET_PRIVATE (self);
-	/*
-	   g_print ("dispose\n");
-	 */
+
+	g_print ("ww_terrainaccessor_dispose\n");
+
 	if (priv->dispose_has_run) {
 		return;
 	}
 	priv->dispose_has_run = TRUE;
 
-	g_object_unref (priv->higher_resolution_subsets);
+	if (priv->higher_resolution_subsets != NULL) {
+		g_object_unref (priv->higher_resolution_subsets);
+	}
 	priv->higher_resolution_subsets = NULL;
 
 	G_OBJECT_CLASS (parent_class)->dispose (obj);
@@ -463,8 +463,7 @@ extract_7z (const gchar * path_bil_7z, const gchar * odir)
 	/*
 	   g_print ("%s %s %s %s\n", argv[0], argv[1], argv[2], argv[3]);
 	 */
-	g_spawn_sync (NULL, argv, NULL, G_SPAWN_SEARCH_PATH | G_SPAWN_STDOUT_TO_DEV_NULL, NULL, NULL, NULL, NULL, NULL,
-				  &err);
+	g_spawn_sync (NULL, argv, NULL, G_SPAWN_SEARCH_PATH | G_SPAWN_STDOUT_TO_DEV_NULL, NULL, NULL, NULL, NULL, NULL, &err);
 	if (err != NULL) {
 		g_print ("spawn error:%s:\n", err->message);
 	}
@@ -488,10 +487,7 @@ ww_terrainaccessor_get_alt (WwTerrainaccessor * obj, gdouble lon, gdouble lat)
 		/*
 		   g_print("w:%.2f  e:%.2f  n:%.2f  s:%.2f\n", one->west, one->east, one->north, one->south);
 		 */
-        /*
-		if (lon > one->west && lon <= one->east && lat >= one->south && lat < one->north) {
-        */
-		if (lon >= one->west && lon < one->east && lat >= one->south && lat < one->north) {
+		if (lon >= one->west && lon <= one->east && lat >= one->south && lat < one->north) {
 			gint16 *tile = one->tile;
 			gdouble deg = priv->level_zero_tile_size_degrees / pow (2.0, one->level);
 			gdouble dlon, dlat;
@@ -596,8 +592,7 @@ data_download (WwTerrainaccessor * obj, gint level, gint x, gint y)
 /* あたえられた範囲のデータが全てディスク上にある状態を用意する */
 /* nx と ny は分割数。ということは、頂点数は nx+1 と ny+1 になることに注意 */
 void
-ww_terrainaccessor_data_prepare (WwTerrainaccessor * obj, gdouble x0, gdouble y0, gdouble x1, gdouble y1, gint nx,
-								 gint ny)
+ww_terrainaccessor_data_prepare (WwTerrainaccessor * obj, gdouble x0, gdouble y0, gdouble x1, gdouble y1, gint nx, gint ny)
 {
 	WwTerrainaccessorPrivate *priv = WW_TERRAINACCESSOR_GET_PRIVATE (obj);
 	gint level = -1;
@@ -736,7 +731,13 @@ ww_terrainaccessor_read_data (WwTerrainaccessor * obj, gdouble x0, gdouble y0, g
 WwTerrainaccessor *
 ww_terrainaccessor_select (WwTerrainaccessor * obj, gdouble x0, gdouble y0, gdouble x1, gdouble y1)
 {
-	WwTerrainaccessorPrivate *priv = WW_TERRAINACCESSOR_GET_PRIVATE (obj);
+	WwTerrainaccessorPrivate *priv;
+
+	if (obj == NULL) {
+		return NULL;
+	}
+
+	priv = WW_TERRAINACCESSOR_GET_PRIVATE (obj);
 
 	if (priv->higher_resolution_subsets != NULL) {
 		WwTerrainaccessor *t = priv->higher_resolution_subsets;
