@@ -40,21 +40,15 @@ struct _WwTexture {
 
 struct _WwTextureClass {
 	GObjectClass parent_class;
-
-	void (*initialized) (WwTexture * texture);
 };
 
 GType ww_texture_get_type (void);
 
-WwTexture *ww_texture_new_dds (const gchar * path_dds, gint width, gint height);
-WwTexture *ww_texture_new_jpg (const gchar * path_jpg, const gchar * path_dds_save);
-WwTexture *ww_texture_new_pixbuf (GdkPixbuf * pixbuf, const gchar * path_dds_save);
-WwTexture *ww_texture_new_data (const gchar * data, gint size, const gchar * path_jpg_save,
-								const gchar * path_dds_save);
+WwTexture *ww_texture_new (void);
+void ww_texture_set_id (WwTexture * texture, guint id);
 WwTexture *ww_texture_copy (WwTexture * texture);
 gboolean ww_texture_bind (WwTexture * texture);
-gboolean ww_texture_is_initialized (WwTexture * texture);
-void ww_texture_gen (WwTexture * texture);
+gboolean ww_texture_is_ok (WwTexture * texture);
 
 G_END_DECLS
 #endif /* __WW_TEXTURE_H__ */
